@@ -1,8 +1,8 @@
 
 /*
- * signal.cc
+ * lava_signal.cc
  * Copyright (C) 2000-2001 by John Heidemann
- * $Id: lava_signal.cc,v 1.3 2001/08/15 15:18:21 johnh Exp $
+ * $Id: lava_signal.cc,v 1.4 2003/06/14 06:05:16 johnh Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License,
@@ -32,13 +32,40 @@
 #include <sys/types.h>
 #include <signal.h>
 
-
 int
 lava_signal(int pid, int sig)
 {
        return kill(pid, sig);
 }
 
+struct signal_mapping {
+	char *name; int sig;
+};
+static struct signal_mapping signal_mapping[] = {
+	{ "HUP", SIGHUP },
+	{ "TERM", SIGTERM },
+	{ "KILL", SIGKILL },
+	{ "STOP", SIGSTOP },
+	{ "CONT", SIGCONT },
+	{ "USR1", SIGUSR1 },
+	{ "USR2", SIGUSR2 },
+	{ NULL, 0 }
+};
+
+int
+lava_named_signal(int pid, const char *sig)
+{
+	int i;
+	// map string to numeric signal
+	for (i = 0; signal_mapping[i].name; i++) {
+		if (strcmp(signal_mapping[i].name, sig) == 0)
+			break;
+	};
+	if (!signal_mapping[i].name)
+		return -1;
+	return lava_signal(pid, signal_mapping[i].sig);
+}
+
 int
 lava_renice(int pid, int niceness)
 {
