@@ -2,7 +2,7 @@
 /*
  * process_list.cc
  * Copyright (C) 1999-2001 by John Heidemann
- * $Id: process_list.cc,v 1.25 2001/08/15 15:16:19 johnh Exp $
+ * $Id: process_list.cc,v 1.28 2003/07/15 03:32:18 johnh Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License,
@@ -22,11 +22,11 @@
 #include "config.h"
 
 #include <stdlib.h>  // atoi
-#include <iostream.h>
 
 #include <unistd.h>
 #include <time.h>
 
+#include <iostream>
 #include <algorithm> // for for_each
 #include <utility>  // for pair
 
@@ -155,7 +155,7 @@ process_list::scan()
 
 	// If we intended to switch real<=>virtual mem,
 	// we've now done so, so forget about the change.
-	report_vm.clear_change();
+	report_vm.commit();
 
 	// autosize, if necessary
 	process_view::autosize();
