@@ -1,8 +1,8 @@
 
 /*
  * tcl_blob.cc
- * Copyright (C) 1999-2000 by John Heidemann
- * $Id: tcl_blob.cc,v 1.44 2000/07/27 19:01:13 johnh Exp $
+ * Copyright (C) 1999-2003 by John Heidemann
+ * $Id: tcl_blob.cc,v 1.61 2003/07/16 04:14:21 johnh Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License,
@@ -23,38 +23,54 @@
 
 #include <stdlib.h>  // atoi
 #include <tcl.h>
-#include <iostream.h>
 
 #include <signal.h>
 
 #include <tcl.h>
 #include <tk.h>
 
+#include <iostream>
+#include <algorithm>
+#include <string>
+
 #include "main.hh"
 #include "tcl_blob.hh"
 #include "process_list.hh"
 #include "lava_signal.hh"
 
-#include <algorithm>
-#include <string>
-
 extern "C" {
 	extern const char *lava_code;
 };
 
 
-// instantiate me
+/*
+ * hook blob proper into tcl_blob
+ */
 blob *
 blob::create_real_blob(process_view *pv)
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	return (blob*) new tcl_blob(pv);
 }
-
 void
 blob::splash(const char *msg)
 {
-	tcl_blob::tcl_splash(msg);
+	tcl_blob::splash(msg);
+}
+void
+blob::init(int argc, char **argv)
+{
+	tcl_blob::init(argc, argv);
+}
+void
+blob::mainloop()
+{
+	tcl_blob::mainloop();
+}
+void
+blob::size_divisor_commit()
+{
+	// ignore it
 }
 
 
@@ -69,11 +85,6 @@ char tcl_blob::result_buf_[TCL_BUF_LEN];
 
 int tcl_blob::pixel_size_ = 1;
 
-bool tcl_blob::lozenge_shaped_ = true;
-int tcl_blob::lozenge_x_shrink_pct_ = 25;  // 0;  // 25;
-int tcl_blob::lozenge_y_buldge_peak_pct_ = 75;
-bool tcl_blob::lozenge_need_recompute_ = true;
-
 int tcl_blob::frame_window_id_ = 0;
 
 static process_list pl;
@@ -81,7 +92,7 @@ static process_list pl;
 
 // static
 int
-tcl_blob::lava_tick_proc(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
+tcl_blob::lava_tick_proc(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[])
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	if (argc != 1) {
@@ -95,7 +106,7 @@ tcl_blob::lava_tick_proc(ClientData clientData, Tcl_Interp *interp, int argc, ch
 
 // static
 int
-tcl_blob::lava_dump_proc(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
+tcl_blob::lava_dump_proc(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[])
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	pl.dump();
@@ -104,7 +115,7 @@ tcl_blob::lava_dump_proc(ClientData clientData, Tcl_Interp *interp, int argc, ch
 
 // static
 int
-tcl_blob::lava_resize_proc(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
+tcl_blob::lava_resize_proc(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[])
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	if (! (argc == 1 || argc == 3 || argc == 4)) {
@@ -127,12 +138,11 @@ tcl_blob::lava_resize_proc(ClientData clientData, Tcl_Interp *interp, int argc,
 	if (argc >= 3)
 		frame_window_id_ = strtol(argv[3], NULL, 16);
 	resize_window(w, h);
+	shape_window();
+
 	double w_scale = x_scale_, h_scale = y_scale_;
 	if (!vertical_)
 		swap(w_scale, h_scale);
-	lozenge_need_recompute_ = true;
-	shape_window();
-
 	snprintf(result_buf_, TCL_BUF_LEN, "%f %f",  w_scale, h_scale);
 	Tcl_SetResult(interp, result_buf_, NULL);
 	return TCL_OK;
@@ -141,7 +151,7 @@ tcl_blob::lava_resize_proc(ClientData clientData, Tcl_Interp *interp, int argc,
 
 // static
 int
-tcl_blob::lava_version_proc(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
+tcl_blob::lava_version_proc(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[])
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	strncpy(result_buf_, VERSION, TCL_BUF_LEN);
@@ -151,7 +161,7 @@ tcl_blob::lava_version_proc(ClientData clientData, Tcl_Interp *interp, int argc,
 
 // static
 int
-tcl_blob::lava_default_resources_proc(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
+tcl_blob::lava_default_resources_proc(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[])
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	strncpy(result_buf_, default_resources.c_str(), TCL_BUF_LEN);
@@ -170,7 +180,7 @@ struct blobs_find_id_p : public unary_function<tcl_blob *,bool> {
 
 // static
 int
-tcl_blob::lava_id_to_info_proc(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
+tcl_blob::lava_id_to_info_proc(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[])
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	if (argc != 2) {
@@ -185,33 +195,20 @@ tcl_blob::lava_id_to_info_proc(ClientData clientData, Tcl_Interp *interp, int ar
 		return TCL_ERROR;
 	};
 	// copy result
-	(*result)->info_to_buf(result_buf_, TCL_BUF_LEN);
+	string s;
+	(*result)->info_to_string(s);
+	assert(s.length() < TCL_BUF_LEN);
+	strcpy(result_buf_, s.c_str());
 	Tcl_SetResult(interp, result_buf_, NULL);
 	return TCL_OK;
 }
 
-struct signal_mapping {
-	char *name; int sig;
-};
-static struct signal_mapping signal_mapping[] = {
-	{ "nice", -1 },
-	{ "unnice", -2 },
-	{ "HUP", SIGHUP },
-	{ "TERM", SIGTERM },
-	{ "KILL", SIGKILL },
-	{ "STOP", SIGSTOP },
-	{ "CONT", SIGCONT },
-	{ "USR1", SIGUSR1 },
-	{ "USR2", SIGUSR2 },
-	{ NULL, 0 }
-};
-
 // static
 int
-tcl_blob::lava_menu_proc(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
+tcl_blob::lava_menu_proc(ClientData clientData, Tcl_Interp *interp, int argc, const char *argv[])
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
-	char *key, *value, *value2;  // before goto to satisfy gcc 2.95.2
+	const char *key, *value, *value2;  // before goto to satisfy gcc 2.95.2
 	if (argc < 2)
 		goto wrong_number_args;
 	key = argv[1];
@@ -232,7 +229,7 @@ tcl_blob::lava_menu_proc(ClientData clientData, Tcl_Interp *interp, int argc, ch
 			strcmp(value, "virtual") == 0 ? VIRTUAL_MEM :
 			strcmp(value, "physical") == 0 ? PHYSICAL_MEM :
 			BOTH_MEM;
-		report_vm.tick_set((vm_style_enum)style);
+		report_vm = style;
 	} else if (strcmp(key, "how") == 0) {
 		if (argc != 3)
 			goto wrong_number_args;
@@ -278,34 +275,18 @@ tcl_blob::lava_menu_proc(ClientData clientData, Tcl_Interp *interp, int argc, ch
 	} else if (strcmp(key, "signal") == 0) {
 		if (argc != 4)
 			goto wrong_number_args;
-		int i;
-		// map string to numeric signal
-		for (i = 0; signal_mapping[i].name; i++) {
-			if (strcmp(signal_mapping[i].name, value) == 0)
-				break;
-		};
-		if (!signal_mapping[i].name) {
-			Tcl_SetResult(interp, "unknown signal name", NULL);
-			return TCL_ERROR;
-		};
-		int sig = signal_mapping[i].sig;
 		int pid = atoi(value2);
 		if (pid == 0) {
 			Tcl_SetResult(interp, "will not signal pid 0", NULL);
 			return TCL_ERROR;
-			return TCL_ERROR;
 		};
 		int e;
-		switch (sig) {
-		case -1: // nice
+		if (strcmp("nice", value) == 0) {
 			e = lava_renice(pid, 5);
-			break;
-		case -2: // unnice
-			e = lava_renice(pid, -5);
-			break;
-		default:
-			e = lava_signal(pid, sig);
-			break;
+		} else if (strcmp("renice", value) == 0) {
+			e = lava_renice(pid, 5);
+		} else {
+			e = lava_named_signal(pid, value);
 		};
 		if (e == -1) {
 			Tcl_SetResult(interp, "signalling error", NULL);
@@ -314,7 +295,7 @@ tcl_blob::lava_menu_proc(ClientData clientData, Tcl_Interp *interp, int argc, ch
 	} else if (strcmp(key, "whoami") == 0) {
 		if (argc != 2)
 			goto wrong_number_args;
-		snprintf(result_buf_, TCL_BUF_LEN, "%d", getuid());
+		snprintf(result_buf_, TCL_BUF_LEN, "%d", (int)getuid());
 		Tcl_SetResult(interp, result_buf_, NULL);
 	} else {
 		Tcl_SetResult(interp, "unknown KEY", NULL);
@@ -328,7 +309,7 @@ tcl_blob::lava_menu_proc(ClientData clientData, Tcl_Interp *interp, int argc, ch
 
 // static
 void
-tcl_blob::init()
+tcl_blob::init(int argc, char **argv)
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	// const char* appname = "lavaps";
@@ -344,30 +325,31 @@ tcl_blob::init()
 	/*
 	 * add our new commands
 	 */
-	(void) Tcl_CreateCommand(interp_, "lava_tick", lava_tick_proc, NULL, NULL);
-	(void) Tcl_CreateCommand(interp_, "lava_id_to_info", lava_id_to_info_proc, NULL, NULL);
-	(void) Tcl_CreateCommand(interp_, "lava_menu", lava_menu_proc, NULL, NULL);
-	(void) Tcl_CreateCommand(interp_, "lava_resize", lava_resize_proc, NULL, NULL);
-	(void) Tcl_CreateCommand(interp_, "lava_dump", lava_dump_proc, NULL, NULL);
-	(void) Tcl_CreateCommand(interp_, "lava_version", lava_version_proc, NULL, NULL);
-	(void) Tcl_CreateCommand(interp_, "lava_default_resources", lava_default_resources_proc, NULL, NULL);
-	// (void) Tcl_CreateCommand(interp_, "lava_move", lava_move_proc, NULL, NULL);
-	// (void) Tcl_CreateCommand(interp_, "lava_grow", lava_grow_proc, NULL, NULL);
-	// (void) Tcl_CreateCommand(interp_, "lava_print", lava_print_proc, NULL, NULL);
-	// (void) Tcl_CreateCommand(interp_, "lava_reverse", lava_reverse_proc, NULL, NULL);
+	(void) Tcl_CreateCommand(interp_, "lava_tick", (Tcl_CmdProc*)lava_tick_proc, NULL, NULL);
+	(void) Tcl_CreateCommand(interp_, "lava_id_to_info", (Tcl_CmdProc*)lava_id_to_info_proc, NULL, NULL);
+	(void) Tcl_CreateCommand(interp_, "lava_menu", (Tcl_CmdProc*)lava_menu_proc, NULL, NULL);
+	(void) Tcl_CreateCommand(interp_, "lava_resize", (Tcl_CmdProc*)lava_resize_proc, NULL, NULL);
+	(void) Tcl_CreateCommand(interp_, "lava_dump", (Tcl_CmdProc*)lava_dump_proc, NULL, NULL);
+	(void) Tcl_CreateCommand(interp_, "lava_version", (Tcl_CmdProc*)lava_version_proc, NULL, NULL);
+	(void) Tcl_CreateCommand(interp_, "lava_default_resources", (Tcl_CmdProc*)lava_default_resources_proc, NULL, NULL);
 
 	/*
 	 * source some files
 	 */
-	if (TCL_OK != Tcl_Eval(interp_, (char *)lava_code)) {
+	char *mutable_code = strdup(lava_code);  // sigh, tcl actually changes the code while running
+	assert(mutable_code != NULL);
+	if (TCL_OK != Tcl_Eval(interp_, mutable_code)) {
 		cerr << "error loading bootstrap: " << Tcl_GetStringResult(interp_) << endl;
 		exit(1);
 	};
+	free(mutable_code);
 	if (TCL_OK != Tcl_Eval(interp_, "main")) {
 		cerr << "error evaling main: " << Tcl_GetStringResult(interp_) << endl;
 		exit(1);
 	};
 	canvas_ = ".c";
+
+	has_base_ = false;
 }
 
 
@@ -381,7 +363,7 @@ tcl_blob::mainloop()
 
 
 tcl_blob::tcl_blob(process_view *pv) :
-	blob(pv), id_(0), did_(0)
+	scaled_blob(pv), id_(0), did_(0)
 {
 	ENTRY_TRACE(__FILE__,__LINE__);
 	// xxx: assume blob initializer called first!
@@ -412,63 +394,9 @@ tcl_blob::~tcl_blob()
 		exit (1);
 	};
 	id_ = 0;
+	did_ = 0;
 }
 
-void
-tcl_blob::lozenge_point(int x, int y, int *nx, int *ny)
-	/*
-	 * Map from x,y into nx,ny
-	 * adjusting for distortion due to lava lamp lozenge shape.
-	 */
-{
-	static int Y_BULDGE,
-		Y_TOP,
-		Y_BOT,
-		X_MID_HALF_WIDTH,
-		X_END_HALF_WIDTH;
-	static double X_REDUCTION_FRAC;
-
-	if (lozenge_need_recompute_) {
-		lozenge_need_recompute_ = false;
-		Y_BULDGE = Y_MAX * lozenge_y_buldge_peak_pct_ / 100;
-		Y_TOP = Y_MAX - Y_BULDGE;
-		Y_BOT = Y_BULDGE;
-		X_MID_HALF_WIDTH = X_MAX / 2;
-		X_END_HALF_WIDTH = X_MAX * lozenge_x_shrink_pct_ / 100;
-		X_REDUCTION_FRAC = ((X_MID_HALF_WIDTH - X_END_HALF_WIDTH) / (1.0 * X_MID_HALF_WIDTH));
-	};
-
-	double frac_x = (x - X_MID_HALF_WIDTH) / (1.0 * X_MID_HALF_WIDTH);
-	bool y_on_top = (y > Y_BULDGE);
-	double abs_frac_y = y_on_top ? (y - Y_BULDGE) / (1.0 * Y_TOP)
-				: (y - Y_BULDGE) / (-1.0 * Y_BOT);
-	double adj_frac_x = frac_x - frac_x * abs_frac_y * X_REDUCTION_FRAC;
-
-	*nx = int(adj_frac_x * X_MID_HALF_WIDTH + X_MID_HALF_WIDTH);
-//	*ny = int((y_on_top ? (abs_frac_y * Y_TOP) : (- abs_frac_y * Y_BOT)) + Y_BULDGE);
-	*ny = y;
-}
-
-
-void
-tcl_blob::screen_point(int x, int y, int *nx, int *ny)
-	/*
-	 * Map from abstract x,y to screen coordinates.
-	 * adjusting for distortion due to lava lamp lozenge shape
-	 * and scaling to screen.
-	 */
-{
-	// distort
-	if (lozenge_x_shrink_pct_ != 0)
-		lozenge_point(x, y, &x, &y);
-
-	// scale to screen
-	*nx = int(x * x_scale_);
-	*ny = int(y * y_scale_);
-	if (!vertical_)
-		swap(*nx, *ny);
-}
-	
 char *
 tcl_blob::list_point(char *bufp, char *eobuf, int x, int y)
 	/*
@@ -476,9 +404,9 @@ tcl_blob::list_point(char *bufp, char *eobuf, int x, int y)
 	 * Adjust for distortion and scale to screen.
 	 */
 {
-	int screen_x, screen_y;
-	screen_point(x, y, &screen_x, &screen_y);
-	snprintf(bufp, eobuf-bufp, "%d %d ", screen_x, screen_y);
+	double screen_x, screen_y;
+	scale_point((double)x, (double)y, &screen_x, &screen_y);
+	snprintf(bufp, eobuf-bufp, "%d %d ", (int)screen_x, (int)screen_y);
 	bufp += strlen(bufp);
 	return bufp;
 }
@@ -560,7 +488,7 @@ tcl_blob::redraw()
 	//
 	if (dark_percentage_) {
 		snprintf(bufp, eobuf-bufp, "set did [%s create polygon ", canvas_);   bufp += strlen(bufp);
-		bufp = list_points(bufp, eobuf, dark_percentage_, 50);
+		bufp = list_points(bufp, eobuf, 100 - dark_percentage_, 50);
 		snprintf(bufp, eobuf-bufp, "-fill %s -smooth 1 -tag p]\n", dark_color_.c_str());   bufp += strlen(bufp);
 		// snprintf(bufp, eobuf-bufp, "-fill %s -outline %s -smooth 1 -tag p]\n", dark_color_.c_str(), bd_color_.c_str());   bufp += strlen(bufp);
 	};
@@ -589,14 +517,13 @@ tcl_blob::redraw()
 		exit (1);
 	};
 	if (dark_percentage_) {
-		char *cp = Tcl_GetStringResult(interp_);
+		const char *cp = Tcl_GetStringResult(interp_);
 		assert(cp != NULL);
 		assert(*cp != 0);
 		id_ = atoi(cp+1);
 		cp = strchr(cp, ' ');
 		assert(cp != NULL);
 		did_ = atoi(cp);
-		
 	} else {
 		id_ = atoi(Tcl_GetStringResult(interp_));
 		did_ = 0;
@@ -609,36 +536,24 @@ tcl_blob::set_hsb(double h, double s, double b)
 	ENTRY_TRACE(__FILE__,__LINE__);
 	blob::set_hsb(h, s, b);
 
-	const char *cs = hsb_to_rgbs(H_, S_, B_);
-	light_color_ = cs;
-	free((void*)cs);
+	string cs = hsb_to_rgb_string(H_, S_, B_);
+	light_color_ = cs.c_str();
 
-	cs = hsb_to_rgbs(H_, S_, 1.0 - B_);
-	bd_color_ = cs;
-	free((void*)cs);
+	cs = hsb_to_rgb_string(H_, S_, 1.0 - B_);
+	bd_color_ = cs.c_str();
 
-	/*
-	 * xxx: this choice (of what the dar color should be)
-	 * probably beongs in process_view.
-	 * Constants:
-	 * 0.0625 is too subtle.
-	 * 0.1 is too much.
-	 */
-	double dark_h = H_ + 0.07;
-	if (dark_h > 1.0)
-		dark_h -= 1.0;
-	double dark_s = S_ + 0.1;
-	if (dark_s > 1.0)
-		dark_s = 1.0;
-	cs = hsb_to_rgbs(dark_h, dark_s, B_);
-	dark_color_ = cs;
-	free((void*)cs);
+	cs = hsb_to_rgb_string(dk_H_, dk_S_, dk_B_);
+	dark_color_ = cs.c_str();
+
+//	if (pv_->pid() == 1913) {
+//		cerr << "test: " << light_color_.c_str() << " " << dark_color_.c_str() << " did " << did_ << " dark_percentage_ " << dark_percentage_  << endl;
+//	};
 
 	schedule_redraw();
 }
 
 void
-tcl_blob::tcl_splash(const char *msg)
+tcl_blob::splash(const char *msg)
 {
 	// cout << msg << endl;
 	char buf[TCL_BUF_LEN];
