@@ -245,11 +245,13 @@ foreach {i} {Nice Unnice {Hang*} {Kill*} {Stop*} {Continue*} {Terminate*}} {\n\
 \n\
 proc init_info {} {\n\
 global rdb\n\
-toplevel .info \n\
+toplevel .info -relief raised -borderwidth 2 -class LavaPS\n\
 wm transient .info .\n\
+wm overrideredirect .info 1\n\
 wm group .\n\
 wm withdraw .info\n\
 wm iconname .info \"\"\n\
+raise .info\n\
 global info_default_wh\n\
 set info_default_wh {24 6}\n\
 if {[debugging]} {\n\
@@ -308,6 +310,7 @@ global info_width info_height root_width root_height\n\
 if {![info exists info_width] || $info_width == 1} {\n\
 set root_width [winfo screenwidth $c]\n\
 set root_height [winfo screenheight $c]\n\
+update idletasks\n\
 set info_width [winfo width $c]\n\
 set info_height [winfo height $c]\n\
 }\n\
@@ -318,6 +321,7 @@ if {[expr $ry + $info_height] >= $root_height} {\n\
 incr ry -$info_height\n\
 }\n\
 wm geometry $c \"+$rx+$ry\"\n\
+raise $c\n\
 }\n\
 \n\
 proc info_click_down {w x y rx ry} {\n\
@@ -496,18 +500,18 @@ init_ticker\n\
 }\n\
 proc init_help {} { global help\n\
 set help(about) {\n\
-<big>Lavaps 1.19</big>\n\
+<big>Lavaps 2.2</big>\n\
 \n\
-Copyright (C) 1998-2001 by John Heidemann. All rights reserved. Comments to <computer>johnh@isi.edu</computer>, latest version at <computer>http://www.isi.edu/~johnh/SOFTWARE/LAVAPS/</computer>.\n\
+Copyright (C) 1998-2003 by John Heidemann. All rights reserved. Comments to <computer>johnh@isi.edu</computer>, latest version at <computer>http://www.isi.edu/~johnh/SOFTWARE/LAVAPS/</computer>.\n\
 \n\
 \n\
 <big>Description</big>\n\
 \n\
-Lavaps is an interactive process-tracking program like ``top'', but with a much different attitude.  Rather than presenting lots of specific info in digital form, it tries to present certain important information in a graphical analog form.  The idea is that you can run it in the background and get a rough idea of what's happening to your system without devoting much concentration to the task.\n\
+LavaPS is an interactive process-tracking program like ``top'', but with a much different attitude.  Rather than presenting lots of specific info in digital form, it tries to present certain important information in a graphical analog form.  The idea is that you can run it in the background and get a rough idea of what's happening to your system without devoting much concentration to the task.\n\
 \n\
-Lavaps was inspired by Mark Weiser's idea of calm computing in this paper:\n\
+LavaPS was inspired by Mark Weiser's idea of calm computing in this paper:\n\
 \n\
-Z<>  ``The Coming Age of Calm Technology'' by Mark Weiser and John Seely Brown. A revised version of Weiser & Brown. ``Designing Calm Technology'', PowerGrid Journal, v 1.01, <computer>http://powergrid.electriciti.com/1.01</computer> (July 1996). October, 1996.  <computer>http://www.ubiq.com/hypertext/weiser/acmfuture2endnote.htm</computer>.\n\
+*  ``The Coming Age of Calm Technology'' by Mark Weiser and John Seely Brown. A revised version of Weiser and Brown. ``Designing Calm Technology'', PowerGrid Journal, v 1.01, <computer>http://powergrid.electriciti.com/1.01</computer> (July 1996). October, 1996.  <computer>http://www.ubiq.com/hypertext/weiser/acmfuture2endnote.htm</computer>.\n\
 \n\
 (This program dedicated to the memory of M.W.--I hope you would have thought it a good hack.)\n\
 \n\
@@ -515,14 +519,9 @@ Z<>  ``The Coming Age of Calm Technology'' by Mark Weiser and John Seely Brown.
 \n\
 }\n\
 set help(basics) {\n\
-<big>Controlling Lavaps</big>\n\
-\n\
-Basic lavaps is quite simple. Blobs live and grow corresponding to processes in the system (see \"BLOBS\"). Clicking the left mouse button on a blob shows information about that process. Clicking the right mouse button pops up menus that let you control lavaps (see \"MENUS\").\n\
-\n\
-\n\
 <big>Blobs</big>\n\
 \n\
-Lavaps is all about blobs of virtual, non-toxic lava. Blobs in lavaps correspond to processes in the system. When a process is started, a new blob is created. When a process exits, the corresponding blob disappears. Blob size is proportional to the amount of memory the process uses. Blob movement is proportional to the amount of time the process runs (if the process never runs, the blob will never move).\n\
+LavaPS is all about blobs of virtual, non-toxic lava. Blobs in LavaPS correspond to processes in the system. When a process is started, a new blob is created. When a process exits, the corresponding blob disappears. Blob size is proportional to the amount of memory the process uses. Blob movement is proportional to the amount of time the process runs (if the process never runs, the blob will never move).\n\
 \n\
 Blobs show several things. First, the basic color (the hue) corresponds to the name of the program which is running.  Emacs is always one color, Netscape another (on my system, blue and yellow). Second, blobs get darker when the process doesn't run. Over time, the process will become nearly black and only  its border will remain colored. Finally, if both physical and virtual memory are shown, then the part of the process will be a slightly different color showing what percentage of the process is not in physical memory.\n\
 \n\
@@ -533,12 +532,17 @@ Blobs also move along the longer distance of the lamp: if you resize it they may
 Please don't ask me about the chemical composition of the virtual lava.\n\
 \n\
 \n\
+<big>Controlling Lavaps (tcl/tk)</big>\n\
+\n\
+Basic LavaPS is quite simple. Blobs live and grow corresponding to processes in the system (see \"BLOBS\"). Clicking the left mouse button on a blob shows information about that process. Clicking the right mouse button pops up menus that let you control LavaPS (see \"MENUS\").\n\
+\n\
+\n\
 \n\
 }\n\
 set help(menus) {\n\
-<big>Menus</big>\n\
+<big>Menus (tcl/tk)</big>\n\
 \n\
-The right mouse button pops up menus which control lavaps, including:\n\
+The right mouse button pops up menus which control LavaPS, including:\n\
 \n\
 <italic>Proc</italic>: control the process under the menu: ``Nice'' it (make it take less CPU), unnice it (the reverse; only works if you're root), or send it a signal. Signals are terminate (the polite way to stop a process; ``terminate'' allows it to clean up after itself), kill (the forcefully way to stop something not listening to terminate), stop and continue (temporarily stop and resume the process), and hang-up (used to restart certain processes). Beware that these commands will be disabled if you don't have privileges to run them, and under some circumstances even ``kill'' won't stop a process.\n\
 \n\
@@ -546,7 +550,7 @@ The right mouse button pops up menus which control lavaps, including:\n\
 \n\
 <italic>What</italic>: track process physical or virtual memory or both. Most modern operating systems can keep all of a process in RAM (physical memory), or can let pages that aren't currently used float out to disk (virtual memory). Virtual memory is always a superset of physical memory. You can track either one, or both. When tracking both, virtual memory appears as a different colored strip down the middle of the process blob.\n\
 \n\
-<italic>How</italic>: controls blob sizing. Putting too little or too much lava in your lava lamp would make it boring or overflow. Lavaps therefore usually runs with patent-pending lava <italic>autosizing</italic> where blobs fill about a quarter of the lamp. This feature can be turned off (at your peril) with the How menu. You can also control the desired size of the blobs (when autosizing is enabled) or the absolute size of the blobs (when it's not) with the <italic>Grow</italic> and <italic>Shrink</italic> options.\n\
+<italic>How</italic>: controls blob sizing. Putting too little or too much lava in your lava lamp would make it boring or overflow. LavaPS therefore usually runs with patent-pending lava <italic>autosizing</italic> where blobs fill about a quarter of the lamp. This feature can be turned off (at your peril) with the How menu. You can also control the desired size of the blobs (when autosizing is enabled) or the absolute size of the blobs (when it's not) with the <italic>Grow</italic> and <italic>Shrink</italic> options.\n\
 \n\
 <italic>Help</italic>: you'll have to figure this one out on your own.\n\
 \n\
@@ -556,9 +560,9 @@ The right mouse button pops up menus which control lavaps, including:\n\
 \n\
 }\n\
 set help(resources) {\n\
-<big>Resources</big>\n\
+<big>Resources (tcl/tk)</big>\n\
 \n\
-Lavaps can configured from X resources (only if they're loaded with xrdb) or with the file <computer>$HOME/.lavapsrc</computer>. In both cases, the format is like:\n\
+The Tcl/Tk version of LavaPS can configured from X resources (only if they're loaded with xrdb) or with the file <computer>$HOME/.lavapsrc</computer>. In both cases, the format is like:\n\
 \n\
 lavaps.autosize: false\n\
 \n\
@@ -590,7 +594,7 @@ The following resources are supported:\n\
 set help(copyright) {\n\
 <big>Copyright</big>\n\
 \n\
-Lavaps is Copyright (C) 1998-2000 by John Heidemann.\n\
+LavaPS is Copyright (C) 1998-2003 by John Heidemann.\n\
 \n\
 This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License, version 2, as published by the Free Software Foundation.\n\
 \n\
@@ -602,19 +606,21 @@ You should have received a copy of the GNU General Public License along with thi
 \n\
 }\n\
 set help(howdoi) {\n\
-<big>How Do I...</big>\n\
+<big>How Do I... (tcl/tk)</big>\n\
 \n\
 Q: The blobs are as jumpy as little rabbits, <italic>How do I make the animation smoother?</italic>\n\
 \n\
-A: Set the checkInterval resource to a smaller value.\n\
+A: Set the checkInterval resource to a smaller value. <italic>Currently, Resources like checkInterval only work in the Tcl version.</italic>\n\
 \n\
-Q: I'm running lavaps on my Timex Sinclair and it consumes a lot of CPU, making my editor ed run slowly. <italic>How can I make lavaps take less CPU?</italic>\n\
+Q: I'm running LavaPS on my Timex Sinclair and it consumes a lot of CPU, making my editor ed run slowly. <italic>How can I make LavaPS take less CPU?</italic>\n\
 \n\
-A: Set the checkInterval resource to a larger value.\n\
+A: Set the checkInterval resource to a larger value. <italic>Currently, Resources like checkInterval only work in the Tcl version.</italic>\n\
 \n\
-Q: Lozenge-shaped lavaps is so cool, but I keep loosing it on my 8000-pixel wide xinerama multi-screen display. <italic>How can I resize lozenge-shaped lavaps since it doesn't have any title bar?</italic>\n\
+Q: Lozenge-shaped LavaPS is so cool, but I keep loosing it on my 8000-pixel wide xinerama multi-screen display. <italic>How can I resize lozenge-shaped LavaPS since it doesn't have any title bar?</italic>\n\
 \n\
-A: (1) Read your window manager documentation, most have ways to resize windows other than the title bar (sometimes using a menu).  (2) Set the geometry explicitly with the -geometry command-line option or the geometry resource.  (3) Put the title bar back (unfortunately loosing the lozenge shape) by setting the ``shaped'' resource to ``false''.\n\
+A: In the Tcl/Tk version: (1) Read your window manager documentation, most have ways to resize windows other than the title bar (sometimes using a menu).  (2) Set the geometry explicitly with the -geometry command-line option or the geometry resource.  (3) Put the title bar back (unfortunately loosing the lozenge shape) by setting the ``shaped'' resource to ``false''.\n\
+\n\
+In the Gtk version: the base has controls to let you move and resize the lava lamp.\n\
 \n\
 \n\
 \n\
